@@ -15,6 +15,7 @@
 
 from datetime import time
 
+from pandas import Timestamp
 from pandas.tseries.holiday import AbstractHolidayCalendar, Day, Easter, GoodFriday, Holiday
 from pytz import timezone
 
@@ -31,6 +32,7 @@ AniversarioSaoPaulo = Holiday(
     'Aniversario de Sao Paulo',
     month=1,
     day=25,
+    end_date='2021-12-31'
 )
 # Carnival Monday
 CarnavalSegunda = Holiday(
@@ -79,7 +81,8 @@ Constitucionalista = Holiday(
     'Constitucionalista',
     month=7,
     day=9,
-    start_date='1997-01-01'
+    start_date='1997-01-01',
+    end_date='2019-12-31'
 )
 # Independence Day
 Independencia = Holiday(
@@ -110,7 +113,8 @@ ConscienciaNegra = Holiday(
     'Dia da Consciencia Negra',
     month=11,
     day=20,
-    start_date='2004-01-01'
+    start_date='2004-01-01',
+    end_date='2019-12-31'
 )
 # Christmas Eve
 VesperaNatal = Holiday(
@@ -138,6 +142,13 @@ AnoNovoSabado = Holiday(
     days_of_week=(FRIDAY,),
 )
 
+##########################
+# Non-recurring holidays
+##########################
+
+Constitucionalista2021 = Timestamp('2021-07-09', tz='UTC')
+ConscienciaNegra2021 = Timestamp('2021-11-20', tz='UTC')
+
 
 class BMFExchangeCalendar(MarketCalendar):
     """
@@ -148,24 +159,24 @@ class BMFExchangeCalendar(MarketCalendar):
 
     Regularly-Observed Holidays:
     - Universal Confraternization (New year's day, Jan 1)
-    - Sao Paulo City Anniversary (Jan 25)
+    - Sao Paulo City Anniversary (Jan 25 until 2021)
     - Carnaval Monday (48 days before Easter)
     - Carnaval Tuesday (47 days before Easter)
     - Passion of the Christ (Good Friday, 2 days before Easter)
     - Corpus Christi (60 days after Easter)
     - Tiradentes (April 21)
     - Labor day (May 1)
-    - Constitutionalist Revolution (July 9 after 1997)
+    - Constitutionalist Revolution (July 9 after 1997 until 2021, skipping 2020)
     - Independence Day (September 7)
     - Our Lady of Aparecida Feast (October 12)
     - All Souls' Day (November 2)
     - Proclamation of the Republic (November 15)
-    - Day of Black Awareness (November 20 after 2004)
+    - Day of Black Awareness (November 20 after 2004 until 2021, skipping 2020)
     - Christmas (December 24 and 25)
     - Day before New Year's Eve (December 30 if NYE falls on a Saturday)
     - New Year's Eve (December 31)
     """
-    aliases = ['BMF']
+    aliases = ['BMF', 'B3']
     regular_market_times = {
         "market_open": ((None, time(10,1)),),
         "market_close": ((None, time(16)),)
@@ -202,6 +213,13 @@ class BMFExchangeCalendar(MarketCalendar):
             AnoNovoSabado,
         ])
 
+    @property
+    def adhoc_holidays(self):
+        return [
+            Constitucionalista2021,
+            ConscienciaNegra2021
+        ]
+
     @property
     def special_opens(self):
         return [
